import { slicedToArray as _slicedToArray } from '../../_virtual/_rollupPluginBabelHelpers.js';
import React, { useState, useRef, useEffect } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import Styles from './Dropdown.styles.scss.js';
import Button from './Button.js';
import IconChevronDown from '../../icons/IconChevronDown.js';
import IconChevronUp from '../../icons/IconChevronUp.js';

var context = classNames.bind(Styles);
var Dropdown = function Dropdown(_ref) {
  var items = _ref.items,
    selected = _ref.selected,
    onChange = _ref.onChange,
    className = _ref.className;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isExpand = _useState2[0],
    setExpand = _useState2[1];
  var _useState3 = useState(selected !== null ? selected : items[0]),
    _useState4 = _slicedToArray(_useState3, 2),
    selectedKey = _useState4[0],
    setSelection = _useState4[1];
  var dropdownItemsRef = useRef(null);
  var isExpandRef = useRef(isExpand);
  var updateToggle = function updateToggle(toggleState) {
    setExpand(toggleState);
    isExpandRef.current = toggleState;
  };
  var handleItemSelection = function handleItemSelection(key) {
    setSelection(key);
    onChange(key);
    updateToggle(false);
  };
  var removeFocus = function removeFocus(_ref2) {
    var target = _ref2.target;
    if (isExpandRef.current && !dropdownItemsRef.current.contains(target)) {
      updateToggle(false);
    }
  };
  useEffect(function () {
    window.addEventListener('click', removeFocus);
    return function () {
      window.removeEventListener('click', removeFocus);
    };
  }, []);
  useEffect(function () {
    setSelection(selected);
  }, [selected]);
  return /*#__PURE__*/React.createElement("span", {
    ref: dropdownItemsRef,
    className: context('dropdown-container', className, {
      expanded: isExpand
    })
  }, /*#__PURE__*/React.createElement(Button, {
    className: context('dropdown-toggle', {
      active: isExpand
    }),
    onClick: function onClick() {
      return updateToggle(!isExpand);
    }
  }, /*#__PURE__*/React.createElement(React.Fragment, null, "Status: ".concat(selectedKey.name), isExpand ? /*#__PURE__*/React.createElement(IconChevronDown, {
    className: Styles.icn
  }) : /*#__PURE__*/React.createElement(IconChevronUp, {
    className: Styles.icn
  }))), isExpand && /*#__PURE__*/React.createElement("ul", {
    className: Styles.list
  }, items.map(function (item, index) {
    return /*#__PURE__*/React.createElement("li", {
      key: item.value,
      className: context('list-item', {
        active: item.value === selectedKey.value
      })
    }, /*#__PURE__*/React.createElement("span", {
      className: Styles['item-text'],
      onClick: function onClick() {
        return handleItemSelection(item);
      },
      role: "button",
      tabIndex: index
    }, item.name));
  })));
};
Dropdown.propTypes = {
  className: PropTypes.string,
  items: PropTypes.array.isRequired,
  onChange: PropTypes.func.isRequired,
  selected: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.object])
};
Dropdown.defaultProps = {
  className: null,
  selected: null
};

export { Dropdown as default };
//# sourceMappingURL=Dropdown.js.map
