import { objectSpread2 as _objectSpread2, defineProperty as _defineProperty, extends as _extends } from '../../../_virtual/_rollupPluginBabelHelpers.js';
import React, { forwardRef, useRef } from 'react';
import { useTooltipTrigger } from '@react-aria/tooltip';
import { useTooltipTriggerState } from '@react-stately/tooltip';
import { useOverlayPosition } from '@react-aria/overlays';
import { useObjectRef, mergeProps } from '@react-aria/utils';
import PropTypes from 'prop-types';
import TooltipLabel from './TooltipLabel.js';
import TooltipArrow from './TooltipArrow.js';
import TooltipTransition from './TooltipTransition.js';

var ARROW_CROSS_SIZE = Math.sqrt(32);
var Tooltip = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var children = _ref.children,
    className = _ref.className,
    delay = _ref.delay,
    hasArrow = _ref.hasArrow,
    placement = _ref.placement,
    title = _ref.title;
  var targetRef = useObjectRef(forwardedRef);
  var tooltipRef = useRef(null);
  var state = useTooltipTriggerState({
    delay: delay
  });
  var _useOverlayPosition = useOverlayPosition({
      targetRef: targetRef,
      overlayRef: tooltipRef,
      placement: placement,
      isOpen: state.isOpen,
      arrowSize: ARROW_CROSS_SIZE,
      // cross size of our arrow, a 4x4 element.
      offset: ARROW_CROSS_SIZE / 2 + 2 // cross size of our arrow, in half, plus our offset size of 2px
    }),
    overlayProps = _useOverlayPosition.overlayProps,
    arrowPlacement = _useOverlayPosition.placement,
    arrowProps = _useOverlayPosition.arrowProps;

  // Override the default close implementation to always close immediately. Standard react-aria
  //  has a minor delay onHoverEnd vs onFocusEnd.
  var close = function close() {
    return state.close(true);
  };
  var _useTooltipTrigger = useTooltipTrigger({
      isOpen: state.isOpen
    }, _objectSpread2(_objectSpread2({}, state), {}, {
      close: close
    }), tooltipRef),
    tooltipProps = _useTooltipTrigger.tooltipProps,
    triggerProps = _useTooltipTrigger.triggerProps;

  // If we're passed an element, make sure that we've only been given one.
  var child = typeof children === 'function' ? children : React.Children.only(children);
  // Manually include a handful of props from react-aria's triggerProps. Otherwise, they block
  // certain events from propagating which can cause conflicts with other listeners in the app.
  var eventedProps = _objectSpread2(_objectSpread2({}, triggerProps), {}, _defineProperty({
    tabIndex: triggerProps.tabIndex,
    'aria-describedby': triggerProps['aria-describedby'],
    onBlur: triggerProps.onBlur,
    onFocus: triggerProps.onFocus,
    onMouseEnter: triggerProps.onPointerEnter,
    onMouseLeave: triggerProps.onPointerLeave,
    onPointerEnter: triggerProps.onPointerEnter,
    onPointerLeave: triggerProps.onPointerLeave
  }, typeof PointerEvent !== 'undefined' ? 'onPointerDown' : 'onClick', close));
  return /*#__PURE__*/React.createElement(React.Fragment, null, typeof child === 'function' ? child({
    triggerProps: eventedProps,
    targetRef: targetRef
  }) : /*#__PURE__*/React.cloneElement(child, _objectSpread2({
    ref: targetRef
  }, mergeProps(child.props, eventedProps))), /*#__PURE__*/React.createElement(TooltipTransition, {
    isOpen: state.isOpen
  }, /*#__PURE__*/React.createElement(TooltipLabel, _extends({
    ref: tooltipRef,
    className: className,
    state: state
  }, overlayProps, tooltipProps), hasArrow && /*#__PURE__*/React.createElement(TooltipArrow, _extends({
    placementAxis: arrowPlacement
  }, arrowProps)), title)));
});
Tooltip.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  delay: PropTypes.number,
  hasArrow: PropTypes.bool,
  placement: PropTypes.oneOf(['top', 'bottom', 'left', 'right']),
  title: PropTypes.node.isRequired
};
Tooltip.defaultProps = {
  className: '',
  delay: 100,
  hasArrow: false,
  placement: 'top'
};
Tooltip.displayName = 'Tooltip';

export { Tooltip as default };
//# sourceMappingURL=Tooltip.js.map
