import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import { formatValue } from '../../utils.js';
import Styles from './NetworkTable.styles.scss.js';
import { VIEWER_FIELDS } from '../../constants.js';
import Tooltip from '../Common/Tooltip/Tooltip.js';

var context = classNames.bind(Styles);
var NetworkCellValue = function NetworkCellValue(_ref) {
  var datakey = _ref.datakey,
    onClick = _ref.onClick,
    payload = _ref.payload,
    unit = _ref.unit;
  var formattedValue = formatValue(datakey, payload[datakey], unit, payload);
  var shouldDisplayTooltip = datakey === VIEWER_FIELDS.file.key || payload.error;
  var getTitle = function getTitle() {
    if (datakey === VIEWER_FIELDS.file.key) {
      return payload.url;
    }
    if (payload.error) {
      return payload.error;
    }
    return formattedValue;
  };
  if (!shouldDisplayTooltip) {
    return /*#__PURE__*/React.createElement("div", {
      className: context('value-text', datakey)
    }, formattedValue);
  }
  return /*#__PURE__*/React.createElement(Tooltip, {
    delay: 500,
    title: getTitle()
  }, /*#__PURE__*/React.createElement("div", {
    className: context('value-text', datakey),
    onClick: onClick
  }, formattedValue));
};
NetworkCellValue.propTypes = {
  datakey: PropTypes.string.isRequired,
  onClick: PropTypes.func,
  payload: PropTypes.object,
  unit: PropTypes.string
};
NetworkCellValue.defaultProps = {
  onClick: function onClick() {},
  payload: {},
  unit: null
};

export { NetworkCellValue as default };
//# sourceMappingURL=NetworkCellValue.js.map
