import React, { useRef, useEffect } from 'react';
import { FixedSizeList } from 'react-window';
import PropTypes from 'prop-types';
import { useNetwork } from '../../state/network/Context.js';
import NetworkTableRow from './NetworkTableRow.js';
import { TABLE_ENTRY_HEIGHT } from '../../constants.js';
import { useResizeObserver } from '../../hooks/useResizeObserver.js';
import Styles from './NetworkTable.styles.scss.js';
import { useTheme } from '../../state/theme/Context.js';
import IconNetworkRequest from '../../icons/IconNetworkRequest.js';

/* eslint no-underscore-dangle: 0 */

var virtualizedTableRow = function virtualizedTableRow(_ref) {
  var data = _ref.data,
    index = _ref.index,
    style = _ref.style;
  var listData = data.listData,
    totalNetworkTime = data.totalNetworkTime,
    handleReqSelect = data.handleReqSelect,
    selectedReqIndex = data.selectedReqIndex;
  var item = listData.get(index);
  return /*#__PURE__*/React.createElement(NetworkTableRow, {
    key: index,
    entry: item,
    maxTime: totalNetworkTime,
    onSelect: handleReqSelect,
    scrollHighlight: selectedReqIndex === item.index,
    style: style
  });
};
var NetworkTableBody = function NetworkTableBody(_ref2) {
  var _listRef$current;
  var height = _ref2.height;
  var _useNetwork = useNetwork(),
    state = _useNetwork.state,
    actions = _useNetwork.actions,
    callbacks = _useNetwork.callbacks;
  var _useTheme = useTheme(),
    enableAutoScroll = _useTheme.enableAutoScroll,
    NoDataPlaceholder = _useTheme.NoDataPlaceholder;
  var numberOfNewEntries = state.get('numberOfNewEntries');
  var data = state.get('data');
  var actualData = state.get('actualData');
  var totalNetworkTime = state.get('totalNetworkTime');
  var selectedReqIndex = state.get('selectedReqIndex');
  var listRef = useRef(null);
  var _useResizeObserver = useResizeObserver((listRef === null || listRef === void 0 || (_listRef$current = listRef.current) === null || _listRef$current === void 0 ? void 0 : _listRef$current._outerRef) || (listRef === null || listRef === void 0 ? void 0 : listRef.current)),
    elementDims = _useResizeObserver.elementDims;
  useEffect(function () {
    actions.setTableHeaderWidth(elementDims.width);
  }, [elementDims]);
  useEffect(function () {
    var _listRef$current2;
    if (enableAutoScroll && listRef !== null && listRef !== void 0 && (_listRef$current2 = listRef.current) !== null && _listRef$current2 !== void 0 && _listRef$current2._outerRef) {
      var _listRef$current3;
      var outerRef = listRef === null || listRef === void 0 || (_listRef$current3 = listRef.current) === null || _listRef$current3 === void 0 ? void 0 : _listRef$current3._outerRef;
      var needToScroll = outerRef.scrollTop + outerRef.offsetHeight + numberOfNewEntries * TABLE_ENTRY_HEIGHT >= outerRef.scrollHeight;
      if (needToScroll) {
        listRef.current._outerRef.scrollTop = outerRef.scrollHeight;
      }
    }
  }, [data, listRef]);
  var handleReqSelect = function handleReqSelect(payload) {
    if (selectedReqIndex === payload.index) {
      return;
    }
    actions.updateScrollToIndex(payload.index);
    actions.selectRequest(payload);
    callbacks.onRequestSelect(payload);
  };
  if (actualData.size === 0) {
    return /*#__PURE__*/React.createElement("div", {
      ref: listRef,
      className: Styles['no-data']
    }, /*#__PURE__*/React.createElement(IconNetworkRequest, {
      className: Styles['network-icon']
    }), NoDataPlaceholder && /*#__PURE__*/React.createElement(NoDataPlaceholder, null), !NoDataPlaceholder && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
      className: Styles.header
    }, "Recording network activity"), /*#__PURE__*/React.createElement("span", {
      className: Styles.subtext
    }, "Perform a request to see the network activity")));
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(FixedSizeList, {
    ref: listRef,
    className: Styles['network-table-body'],
    height: height,
    itemCount: data.size,
    itemData: {
      listData: data,
      totalNetworkTime: totalNetworkTime,
      handleReqSelect: handleReqSelect,
      selectedReqIndex: selectedReqIndex
    },
    itemSize: TABLE_ENTRY_HEIGHT
  }, virtualizedTableRow));
};
NetworkTableBody.propTypes = {
  height: PropTypes.number.isRequired
};

export { NetworkTableBody as default };
//# sourceMappingURL=NetworkTableBody.js.map
