import { objectSpread2 as _objectSpread2, slicedToArray as _slicedToArray } from '../../_virtual/_rollupPluginBabelHelpers.js';
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import { ROW_ID_PREFIX } from '../../constants.js';
import Styles from './NetworkTable.styles.scss.js';
import TimeChart from './TimeChart.js';
import NetworkCellValue from './NetworkCellValue.js';
import { getStatusClass, getViewerFields } from '../../utils.js';
import { useTheme } from '../../state/theme/Context.js';
import { useNetwork } from '../../state/network/Context.js';

var context = classNames.bind(Styles);
var NetworkTableRow = function NetworkTableRow(_ref) {
  var entry = _ref.entry,
    maxTime = _ref.maxTime,
    onSelect = _ref.onSelect,
    scrollHighlight = _ref.scrollHighlight,
    style = _ref.style;
  var _useNetwork = useNetwork(),
    state = _useNetwork.state;
  var showReqDetail = state.get('showReqDetail');
  var _useTheme = useTheme(),
    showWaterfall = _useTheme.showWaterfall;
  var columns = getViewerFields(showReqDetail, showWaterfall);
  var rowProps = {
    className: context('network-table-row', getStatusClass(entry), {
      highlight: scrollHighlight
    }),
    id: ROW_ID_PREFIX + entry.index,
    onClick: function onClick() {
      return onSelect(entry);
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    style: _objectSpread2({}, style)
  }, /*#__PURE__*/React.createElement("div", rowProps, Object.entries(columns).map(function (_ref2) {
    var _ref3 = _slicedToArray(_ref2, 2),
      datakey = _ref3[0],
      _ref3$ = _ref3[1],
      key = _ref3$.key,
      unit = _ref3$.unit;
    return /*#__PURE__*/React.createElement("div", {
      key: key,
      className: context('table-column', datakey, {
        'limited-cols': showReqDetail
      }, {
        'show-waterfall': showWaterfall
      })
    }, key === 'waterfall' && entry.time ? /*#__PURE__*/React.createElement(TimeChart, {
      maxTime: maxTime,
      timings: entry.timings
    }) : /*#__PURE__*/React.createElement(NetworkCellValue, {
      datakey: key,
      onClick: rowProps.onClick,
      payload: entry,
      unit: unit
    }));
  })));
};
NetworkTableRow.propTypes = {
  entry: PropTypes.object.isRequired,
  maxTime: PropTypes.number.isRequired,
  onSelect: PropTypes.func.isRequired,
  scrollHighlight: PropTypes.bool.isRequired,
  style: PropTypes.object
};
NetworkTableRow.defaultProps = {
  style: {}
};

export { NetworkTableRow as default };
//# sourceMappingURL=NetworkTableRow.js.map
