import { slicedToArray as _slicedToArray } from '../_virtual/_rollupPluginBabelHelpers.js';
import React, { useState, useRef, useEffect } from 'react';
import classNames from 'classnames/bind';
import NetworkTableHeader from '../Components/NetworkTable/NetworkTableHeader.js';
import { useNetwork } from '../state/network/Context.js';
import ImportHar from '../Components/Import/ImportHAR.js';
import Styles from './NetworkTableContainer.styles.scss.js';
import ErrorMessage from '../Components/ErrorMessage.js';
import { useTheme } from '../state/theme/Context.js';
import InputHAR from '../Components/Import/InputHAR.js';
import NetworkTableBody from '../Components/NetworkTable/NetworkTableBody.js';
import { TABLE_HEADER_HEIGHT } from '../constants.js';
import { useResizeObserver } from '../hooks/useResizeObserver.js';

var context = classNames.bind(Styles);
var NetworkTableContainer = function NetworkTableContainer() {
  var _useNetwork = useNetwork(),
    state = _useNetwork.state;
  var _useTheme = useTheme(),
    showImportHar = _useTheme.showImportHar,
    showWaterfall = _useTheme.showWaterfall;
  var actualData = state.get('actualData');
  var error = state.get('error');
  var showReqDetail = state.get('showReqDetail');
  var _useState = useState(0),
    _useState2 = _slicedToArray(_useState, 2),
    tableBodyHeight = _useState2[0],
    setTableBodyHeight = _useState2[1];
  var ref = useRef();
  var _useResizeObserver = useResizeObserver(ref === null || ref === void 0 ? void 0 : ref.current),
    elementDims = _useResizeObserver.elementDims;
  useEffect(function () {
    if (ref !== null && ref !== void 0 && ref.current && elementDims.height) {
      setTableBodyHeight(ref.current.clientHeight - TABLE_HEADER_HEIGHT);
    }
  }, [ref === null || ref === void 0 ? void 0 : ref.current, actualData, elementDims]);
  if (error) {
    return /*#__PURE__*/React.createElement(ErrorMessage, error);
  }
  if (!actualData.size && showImportHar) {
    return /*#__PURE__*/React.createElement("section", {
      className: Styles['har-selection']
    }, /*#__PURE__*/React.createElement(ImportHar, {
      showButton: false
    }), /*#__PURE__*/React.createElement(InputHAR, null));
  }
  return /*#__PURE__*/React.createElement("section", {
    ref: ref,
    className: context('table-container', {
      'hide-waterfall': !showWaterfall
    }, {
      'limited-cols': showReqDetail
    })
  }, /*#__PURE__*/React.createElement(NetworkTableHeader, null), /*#__PURE__*/React.createElement(NetworkTableBody, {
    height: tableBodyHeight
  }));
};

export { NetworkTableContainer as default };
//# sourceMappingURL=NetworkTableContainer.js.map
